@@ -2,8 +2,6 @@ import datetime
 import unittest
 from decimal import Decimal
 
-import pytz
-
 from twilio.base import deserialize
 
 
@@ -21,7 +19,7 @@ class Iso8601DateTestCase(unittest.TestCase):
 class Iso8601DateTimeTestCase(unittest.TestCase):
     def test_parsable(self):
         actual = deserialize.iso8601_datetime("2015-01-02T03:04:05Z")
-        expected = datetime.datetime(2015, 1, 2, 3, 4, 5, 0, pytz.utc)
+        expected = datetime.datetime(2015, 1, 2, 3, 4, 5, 0, datetime.timezone.utc)
         self.assertEqual(expected, actual)
 
     def test_not_parsable(self):
